.. figure:: _static/png/logo_pyws.png

pywatemsedem
============

The pywatemsedem package is a Python wrapper for.
`WaTEM/SEDEM <https://watem-sedem.github.io/watem-sedem/>`_.
The aim of the pywatemsedem package is to:

 - Automate GIS IO processing.
 - Provide tools to interact with WaTEM/SEDEM.
 - Run WaTEM/SEDEM

The package is implemented in Python and best used with the tutorial
notebooks available on this page.

Getting started
---------------

This package makes use of Python (and a number of dependencies such as
Geopandas, Rasterio, Pandas and Numpy). To install the package:

::

    pip install pywatemsedem

.. note::

    Note that it relies on dependencies you need to install yourselves, see
     `installation instructions <https://watem-sedem.github.io/pywatemsedem/installation.html>`_ for more information.

Documentation
-------------
The documentation can be found on the
`pywatemsedem documentation page <http://watem-sedem.github.io/pywatemsedem>`_.

Code
----
The open-source code can be found on
`GitHub <https://github.com/watem-sedem/pywatemsedem/>`_.

License
-------
This project is licensed under MIT, see
`license <https://watem-sedem.github.io/pywatemsedem/license.html>`_ for more information.

Projects
--------

The pywatemsedem package has been used in following projects:

.. image:: https://watem-sedem.github.io/pywatemsedem/_static/png/projects/tripleC.jpg
 :target: http://www.triple-c-water.eu


Contact
-------
For technical questions, we refer to the documentation. If you have a
technical issue with running the model, or if you encounter a bug, please
use the issue-tracker on github:
`https://github.com/watem-sedem/pywatemsedem/issues <https://github.com/pywatemsedem/issues>`_


Powered by
----------

.. figure:: https://watem-sedem.github.io/pywatemsedem/_static/png/DepartementOmgeving_logo.png
 :target: https://omgeving.vlaanderen.be/

.. figure:: https://watem-sedem.github.io/pywatemsedem/_static/png/VMM_logo.png
 :target: https://vmm.be/

.. figure:: https://watem-sedem.github.io/pywatemsedem/_static/png/fluves_logo.png
 :target: https://fluves.com/

.. figure:: https://watem-sedem.github.io/pywatemsedem/_static/png/KULeuven_logo.png
 :target: https://aow.kuleuven.be/
